local ADDON_NAME = "DBM-Nighthold"

local mainFrame = CreateFrame("Frame", "DBM-Nighthold-DBH")
local iconedAssignments = {RAID_TARGET_1, RAID_TARGET_2, RAID_TARGET_3, RAID_TARGET_4, RAID_TARGET_5}
local iconedVoiceAssignments = {"mm1", "mm2", "mm3", "mm4", "mm5"}

-- /script DBM:StartCombat(DBM:GetModByName("1725"))
local function addonLoaded()
	DBM:AddMsg("DBH DBM-Nighthold assist addon loading", "DBH-DBM")
	local mod	= DBM:GetModByName("1725")
	self = mod
	local L		= mod:GetLocalizedStrings()
	
	mod:SetUsedIcons(6, 5, 4, 3, 2, 1) --Used for Timebomb icon TBIcon
	mod:RegisterCombat("combat")
	
	mod.vb.TBIcon = 1
	local timeBombDebuff = GetSpellInfo(206617)
	-- Reporting marks
	local reportedMark = false -- cleared on combatstart and aura removed
	local specWarnTimeBomb = mod:NewSpecialWarningYou(206617, nil, nil, nil, 3, 4) -- 3 = 6
	local specWarnTimeBombPosition = mod:NewSpecialWarningYouPos(206617, nil, false, nil, 1, 4) -- 3 = 6
	local voiceTimeBomb = mod:NewVoice(206617)--Runout
	
	function mod:RAID_TARGET_UPDATE()
		-- Let's hope this stuff works
		local playerMark = GetRaidTargetIndex("player")
		if playerMark then
			if playerMark < 7 and not reportedMark then -- 7 and 8 are cross and skull
				reportedMark = true -- Ensure we don't report it twice
				specWarnTimeBombPosition:Show(iconedAssignments[i])
				specWarnTimeBomb:Show()
				voiceTimeBomb:Play(iconedVoiceAssignments[i])
			end
		end
	end
	
	local function delayAddonLoad()
		DBM:AddMsg("DBH DBM-Nighthold assist addon loaded", "DBH-DBM")
		-- Add raid target marker updating into the loop
		-- RegisterEventsInCombat prevent adding additional events after setting the initial values so we append.
		table.insert(mod.inCombatOnlyEvents, "RAID_TARGET_UPDATE")
		local orgOnCombatStart = mod.OnCombatStart -- cache the old so we can call it
		
		local function onCombatStart(delay)
			mod.vb.TBIcon = 1
			reportedMark = false -- ensure it is cleared
			DBM:AddMsg("Combat started with DBH assisting on Timebomb markers!", "DBH-DBM")
			mod:RegisterOnUpdateHandler(function(self, elapsed)
				if not self:IsInCombat() then return end
				local curTime = GetTime()
				for uId in DBM:GetGroupMembers() do
					local _, _, _, _, _, _, expires, _, _, _, _, _, _, _, _, timeMod = UnitDebuff(uId, timeBombDebuff)
					if expires then
						local debuffTime = expires - curTime
						if debuffTime < 11 then
							local playerIcon = self:GetIcon(uId)
							if playerIcon == nil then -- The user has no icon yet
								if self.vb.TBIcon == 7 then -- start over with icons
									self.vb.TBIcon = 1
								end
								local number = self.vb.TBIcon
								self.vb.TBIcon = self.vb.TBIcon + 1
								self:SetIcon(uId, number)
							end
						end
					end
				end
			end, 0.5)
			
			orgOnCombatStart(mod)
		end
		mod.OnCombatStart = onCombatStart
		
		local orgSPELL_AURA_REMOVED = mod.SPELL_AURA_REMOVED -- cache the old so we can call it
		local function spell_aura_removed(_args, args)
			local spellId = args.spellId
			if spellId == 206617 then
				mod:RemoveIcon(args.destName)
				if args:IsPlayer() then
					reportedMark = false
				end
			end
			orgSPELL_AURA_REMOVED(mod, args)
		end
		mod.SPELL_AURA_REMOVED = spell_aura_removed
	end
	
	DBM:Schedule(5, delayAddonLoad)
end

do
	local function onEvent(self, event, ...)
		if event == "ADDON_LOADED" and select(1, ...) == ADDON_NAME then
			addonLoaded()
			mainFrame:UnregisterEvent("ADDON_LOADED")
		end
	end

	mainFrame:SetScript("OnEvent", onEvent)
	mainFrame:RegisterEvent("ADDON_LOADED")
end
